==> msgcab-0.0.0.tar.gz: msgcab-0.0.0/msgcab/database/sqlite.rb <==
# Copyright (C) 2004, 2005  National Institute of Advanced Industrial Science and Technology
#
# This file is part of msgcab.
#
# msgcab is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# msgcab is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with msgcab; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

require 'sqlite'

module MsgCab
  class SQLite
    def initialize
      path = Config['url']
      unless path
        path = Config.absolute_path(Config['database_path'] ||
                                      './db/database.sqlite3')
        path.dirname.mkdir unless path.dirname.exist?
      end
      @db = ::SQLite::Database.new(path.to_s)
      @db.transaction
    end

    def commit
      @db.commit
    end

    def disconnect
      commit if @db.transaction_active?
      # @db.close
    end

    def prepare(stmt, name = nil)
      result = @db.prepare(stmt)
      def result.execute(*bind_vars)
        @result = super(*bind_vars)
      end
      def result.fetch_all
        @result.to_a
      end
      def result.fetch
        @result.next
      end
      result
    end

    def execute(stmt, *bind_vars)
      @db.execute(stmt, *bind_vars)
    end

    def select_all(stmt, *bind_vars)
      execute(stmt, *bind_vars)
    end

    def select_one(stmt, *bind_vars)
      execute(stmt, *bind_vars)[0]
    end

    def tables
      execute(<<'End').collect {|row| row[0]}
select name from sqlite_master where type='table'
End
    end
  end
end

==> msgcab-0.0.3.tar.gz: msgcab-0.0.3/msgcab/database/sqlite.rb <==
# Copyright (C) 2004, 2005  National Institute of Advanced Industrial Science and Technology
#
# This file is part of msgcab.
#
# msgcab is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# msgcab is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with msgcab; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

require 'sqlite'

module MsgCab
  class SQLite
    def initialize
      path = Config['url']
      unless path
        path = Config.absolute_path(Config['database', 'path'] ||
                                      './db/database.sqlite')
        path.dirname.mkdir unless path.dirname.exist?
      end
      @db = ::SQLite::Database.new(path.to_s)
      @db.transaction
    end

    def commit
      @db.commit
    end

    def disconnect
      commit if @db.transaction_active?
      # @db.close
    end

    def prepare(stmt, name = nil)
      result = @db.prepare(stmt)
      def result.execute(*bind_vars)
        @result = super(*bind_vars)
      end
      def result.fetch_all
        @result.to_a
      end
      def result.fetch
        @result.next
      end
      result
    end

    def execute(stmt, *bind_vars)
      @db.execute(stmt, *bind_vars)
    end

    def select_all(stmt, *bind_vars)
      execute(stmt, *bind_vars)
    end

    def select_one(stmt, *bind_vars)
      execute(stmt, *bind_vars)[0]
    end

    def tables
      execute(<<'End').collect {|row| row[0]}
select name from sqlite_master where type='table'
End
    end
  end
end
